pub struct PartialWriteError {
pub line_errors: Vec<LineError>,
}Expand description
Returned when accept_partial=true and the server rejected one or more lines.
The server accepts the valid lines and returns HTTP 400 with a JSON body
listing every rejected line. Check line_errors for details.
Fields
line_errors: Vec<LineError>Trait Implementations
Sourceimpl Debug for PartialWriteError
impl Debug for PartialWriteError
Sourceimpl Display for PartialWriteError
impl Display for PartialWriteError
Sourceimpl Error for PartialWriteError
impl Error for PartialWriteError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<PartialWriteError> for Error
impl From<PartialWriteError> for Error
Sourcefn from(source: PartialWriteError) -> Self
fn from(source: PartialWriteError) -> Self
Converts to this type from the input type.